<?xml version="1.0" encoding="UTF-8"?>
<!-- Conversion Hdoc to SimpleChain -->
<xsl:stylesheet 
    xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
    xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
    xmlns:ns="http://www.utc.fr/ics/hdoc/xhtml"
    xmlns:hdoc="utc.fr/ics:hdoc"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    exclude-result-prefixes="ns"
    version="2.0">
    <xsl:output method="xml" encoding="UTF-8" indent="yes"></xsl:output>
    
     <xsl:template match="/">
        <!-- go to the next line before inserting the processing-instruction -->
        <xsl:text>&#xA;</xsl:text>
        <xsl:processing-instruction name="oxygen">
            <!-- put text between xsl:text elements or there will be whitespaces -->
            <!-- TO ADD : the link to the RNG Schema of SimpleChain -->
            <xsl:text>RNGSchema="http://tuxa.sme.utc/~nf29a006/rng_sc/hdoc_html.rng"</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>type="xml"</xsl:text>
        </xsl:processing-instruction>
        
        <sc:item xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
            xsl:exclude-result-prefixes="hdoc sp">
            <xsl:apply-templates select="*"></xsl:apply-templates>
        </sc:item>
    </xsl:template>
    
    <!-- matches the html element -->
    <xsl:template match="ns:html">
        <hdoc:html>
            <xsl:apply-templates select="*"></xsl:apply-templates>
        </hdoc:html>
    </xsl:template>
    
    <!-- matches the head element -->
    <xsl:template match="ns:head">
        <sp:head>
            <hdoc:metadata>
                <xsl:apply-templates select="*"></xsl:apply-templates>
            </hdoc:metadata>
        </sp:head>
    </xsl:template>
    
    <!-- matches the title element -->
    <xsl:template match="ns:title">
        <sp:title>
            <xsl:value-of select="."></xsl:value-of>
        </sp:title>
    </xsl:template>
    
    <!-- matches the meta element with the attribute charset -->
    <xsl:template match="ns:meta[@charset!='']">
        <sp:meta>
            <xsl:value-of select="@charset"></xsl:value-of>
        </sp:meta>
    </xsl:template>
    
    <!-- matches the meta element with the attribute generator -->
    <xsl:template match="ns:meta[@generator!='']">
        <sp:metagen>
            <xsl:value-of select="@generator"></xsl:value-of>
        </sp:metagen>
    </xsl:template>
    
    <!-- matches the meta element with the attribute charset -->
    <xsl:template match="ns:meta[@name!='' and @content!='']">
        <sp:metasub>
            <sp:type><xsl:value-of select="@name"></xsl:value-of></sp:type>
            <sp:content><xsl:value-of select="@content"></xsl:value-of></sp:content>
        </sp:metasub>
    </xsl:template>
    
    <!-- matches the body element -->
    <xsl:template match="ns:body">
        <sp:body>
            <hdoc:body>
                <xsl:apply-templates select="*"></xsl:apply-templates>
            </hdoc:body>
        </sp:body>
    </xsl:template>
    
    <!-- matches the section element -->
    <xsl:template match="ns:section">
        <sp:section>
            <hdoc:section>
                <xsl:apply-templates select="*"></xsl:apply-templates>
            </hdoc:section>
        </sp:section>
    </xsl:template>
    
    <!-- matches the header element -->
    <xsl:template match="ns:header">
        <hdoc:headerdata>
            <sp:headergroup>
                <xsl:apply-templates select="*"></xsl:apply-templates>
            </sp:headergroup>
        </hdoc:headerdata>
    </xsl:template>
    
    <!-- matches the div element (@:author) inside header -->
    <xsl:template match="ns:header//ns:div[@data-hdoc-type='author']">
        <sp:authorvalue><xsl:value-of select="."></xsl:value-of></sp:authorvalue>
    </xsl:template>
    
    <!-- matches the div element (@:date) inside header -->
    <xsl:template match="ns:header//ns:div[@data-hdoc-type='date']">
        <sp:datevalue><xsl:value-of select="."></xsl:value-of></sp:datevalue>
    </xsl:template>
    
    <!-- matches the div element (@:rights) inside header -->
    <xsl:template match="ns:header//ns:div[@data-hdoc-type='rights']">
        <sp:rightsvalue><xsl:value-of select="."></xsl:value-of></sp:rightsvalue>
    </xsl:template>
    
    <!-- matches the div element direct child of section -->
    <xsl:template match="ns:section/ns:div">
        <sp:div>
            <hdoc:content>
                <xsl:if test="string-length(@data-hdoc-type)!=0">
                    <hdoc:datahdoctype>
                        <sp:typediv><xsl:value-of select="@data-hdoc-type"></xsl:value-of></sp:typediv>
                    </hdoc:datahdoctype>
                </xsl:if>
                
                <xsl:if test="string-length(./ns:h6/text())!=0">
                    <sp:h6>
                        <hdoc:txtbase>
                            <sc:para xml:space="preserve" sc:id="t{generate-id()}">
                               <xsl:value-of select="./ns:h6"></xsl:value-of>
                            </sc:para>
                        </hdoc:txtbase>
                    </sp:h6>
                </xsl:if>
                
                <sp:flow>
                    <hdoc:flow>
                        <xsl:apply-templates select="*"></xsl:apply-templates>
                    </hdoc:flow>
                </sp:flow>           
            </hdoc:content>
        </sp:div>
    </xsl:template>
    
    <!-- matches the data-hdoc-type attribute inside section -->
    <!-- <xsl:template match="ns:section//ns:div[string-length(@data-hdoc-type)!=0]" name="datahdoc-template">
        <hdoc:datahdoctype>
            <sp:typediv><xsl:value-of select="@data-hdoc-type"></xsl:value-of></sp:typediv>
        </hdoc:datahdoctype>
    </xsl:template>-->
    
    <!-- matches the h6 element inside section -->
    <xsl:template match="ns:div/ns:h6">
        <!-- this template does nothing because the h6 element has already been 
            transformed on the a previous template (ns:section/ns:div) -->
        <!--<sp:h6>
            <hdoc:txtbase>
                <sc:para xml:space="preserve" sc:id="t38">
                    <xsl:value-of select="."></xsl:value-of>
                </sc:para>
            </hdoc:txtbase>
        </sp:h6>-->
    </xsl:template>
    
    <!-- matches the p element inside div -->
    <xsl:template match="ns:div/ns:p">
        <sp:textflow>
            <hdoc:textflow>
                <sc:para xml:space="preserve" sc:id="t{generate-id()}">
                    <xsl:value-of select="."></xsl:value-of>                    
                </sc:para>
            </hdoc:textflow>
        </sp:textflow>
    </xsl:template>
    
    <!-- matches the footer element -->
    <xsl:template match="ns:footer">
        <sp:footersec>
            <hdoc:footercode>                
                <xsl:apply-templates select="*"></xsl:apply-templates>
            </hdoc:footercode>
        </sp:footersec>        
    </xsl:template>
    
    <!-- matches the div element inside footer -->
    <xsl:template match="ns:footer/ns:div">
        
        <!-- TODO -->
        <sp:footergroup>
            <xsl:if test="@data-hdoc-type='tags'">
                <sp:tagsvalues>
                    <xsl:for-each select="./ns:span">
                        <xsl:value-of select="."></xsl:value-of>
                        <xsl:if test="position() != last()">
                            <xsl:text>,</xsl:text>
                        </xsl:if>                        
                    </xsl:for-each>
                </sp:tagsvalues>
            </xsl:if>
            <!-- <xsl:if test="following-sibling::node()[@data-hdoc-type='categories']"> --> 
            <xsl:if test="@data-hdoc-type='categories'">
                <sp:categoriesvalue>
                    <xsl:for-each select="./ns:span">
                        <xsl:value-of select="."></xsl:value-of>
                        <xsl:if test="position() != last()">
                            <xsl:text>,</xsl:text>
                        </xsl:if>                        
                    </xsl:for-each>
                </sp:categoriesvalue>
            </xsl:if>
        </sp:footergroup>
    </xsl:template>
    
    <!-- matches the table element inside div -->
    <xsl:template match="ns:div//ns:table">
        <sp:tableflow>
            <hdoc:tableflow>
                <!-- how to handle the sc:id here ?  -->
                <sc:table role="" sc:id="t{generate-id(node())}">
                    <!-- TODO -->
                    <!-- for each tr generate row -->
                    <!-- for each td generate cell -->
                    <xsl:apply-templates select="*"></xsl:apply-templates>
                </sc:table>
            </hdoc:tableflow>
        </sp:tableflow>
    </xsl:template>
    
    <!-- matches the caption element -->
    <xsl:template match="ns:caption">
        <sc:caption xml:space="preserve"><xsl:value-of select="."></xsl:value-of></sc:caption>
    </xsl:template>
    
    <xsl:template match="ns:tr[1]">
        <!-- generate row -->
        <xsl:for-each select="./ns:td">
            <sc:column sc:id="t{generate-id(node())}c" width="25"/>
        </xsl:for-each>
        <sc:row sc:id="t{generate-id(node())}r">
            <xsl:apply-templates select="*"></xsl:apply-templates>
        </sc:row>
    </xsl:template>
    
    <!-- matches the tr element -->
    <xsl:template match="ns:tr">
        <!-- generate row -->
        
        <sc:row sc:id="t{generate-id()}r">
            <xsl:apply-templates select="*"></xsl:apply-templates>
        </sc:row>
    </xsl:template>
    
    
    
    <!-- matches the td element -->
    <xsl:template match="ns:td">
        <!-- generate cell -->
        <sc:cell sc:id="t{generate-id()}c">
            <sc:para xml:space="preserve" sc:id="t{generate-id()}p">
                <xsl:value-of select="./ns:p"></xsl:value-of>
            </sc:para>
        </sc:cell>
    </xsl:template>
    
    <!-- matches the h1 element -->
    <xsl:template match="ns:h1">
        <sp:h1value>
            <xsl:value-of select="."></xsl:value-of>
        </sp:h1value>
    </xsl:template>
    
    <!-- matches the a element -->
    <xsl:template match="ns:a">
        <sc:uLink role="url" sc:id="t{generate-id()}" url="{@href}">
            <xsl:value-of select="."></xsl:value-of>
        </sc:uLink>
    </xsl:template>
    
    <!-- matches the ul element -->
    <xsl:template match="ns:ul">
        <sp:textflow>
            <hdoc:textflow>
                <sc:simpleList sc:id="t24">
                    <xsl:apply-templates select="*"></xsl:apply-templates>
                </sc:simpleList>
            </hdoc:textflow>
        </sp:textflow>
    </xsl:template>
    
    <!-- matches the first li element -->
    <xsl:template match="ns:ul/ns:li[1]">
        <sc:member xml:space="preserve" sc:id="{generate-id()}">
           <!--<xsl:value-of select="./ns:p"></xsl:value-of>-->
            <xsl:apply-templates select="*"></xsl:apply-templates>
        </sc:member>        
    </xsl:template>
    
    <!-- matches the li element -->
    <xsl:template match="ns:ul/ns:li">
        <sc:member xml:space="preserve">
            <xsl:apply-templates select="*"></xsl:apply-templates>
        </sc:member>        
    </xsl:template>
    
    <!-- matches the ol element -->
    <xsl:template match="ns:ol">
        <sp:textflow>
            <hdoc:textflow>
                <sc:orderedList sc:id="t{generate-id()}">                    
                    <xsl:apply-templates select="*"></xsl:apply-templates>
                </sc:orderedList>
            </hdoc:textflow>
        </sp:textflow>
    </xsl:template>
    
    <!-- matches the first li element inside ol -->
    <xsl:template match="ns:ol/ns:li[1]">
        <sc:listItem sc:id="t{generate-id()}">
            <sc:para xml:space="preserve" sc:id="t{generate-id()}">element1</sc:para>
        </sc:listItem>
    </xsl:template>
    
    <!-- matches the li element inside ol -->
    <xsl:template match="ns:ol/ns:li">
        <sc:listItem sc:id="t{generate-id()}">
            <sc:para xml:space="preserve">
                <xsl:value-of select="."></xsl:value-of>
            </sc:para>
        </sc:listItem>
    </xsl:template>
    
    <!-- matches the object element -->
    <xsl:template match="ns:object">
        <sp:objectflow>
            <hdoc:objecttype>
                <sp:type><xsl:value-of select="@type"></xsl:value-of></sp:type>
                <sp:data><xsl:value-of select="@data"></xsl:value-of></sp:data>
            </hdoc:objecttype>
        </sp:objectflow>
    </xsl:template>
    
    <!-- matches the audio element -->
    <xsl:template match="ns:audio">
        <sp:audioflow sc:refUri="{@src}"/>
    </xsl:template>
    
    <!-- matches the img element -->
    <xsl:template match="ns:img">
        <sp:imageflow sc:refUri="{@src}"/>
    </xsl:template>
    
    <!-- matches the video element -->
    <xsl:template match="ns:video">
        <sp:videoflow sc:refUri="{@src}"/>
    </xsl:template>
    
    <!-- matches the p element -->
    <!-- how to handle the sc:id here ? with generate-id()  -->
    <!--<xsl:template match="ns:p">
        
        <sp:textflow>
            <hdoc:textflow>
                <sc:para xml:space="preserve" sc:id="t2"><xsl:value-of select="."></xsl:value-of></sc:para>
            </hdoc:textflow>
        </sp:textflow>
    </xsl:template>-->
</xsl:stylesheet>
